.. setuptools-odoo documentation master file, created by
   sphinx-quickstart on Sat Oct  1 16:56:21 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. include:: ../CHANGES.rst

.. include:: ../DEVELOP.rst

